@@ -2,9 +2,11 @@
 $:.unshift File.expand_path("../../lib", __FILE__)
 
 begin
-  gem "coveralls"
-  require "coveralls"
-  Coveralls.wear!
+  if ENV["COVERALLS"]
+    gem "coveralls"
+    require "coveralls"
+    Coveralls.wear!
+  end
 rescue Gem::LoadError
 end
 
@@ -26,7 +28,7 @@ class Rake::TestCase < Minitest::Test
     include Rake::TaskManager
   end
 
-  RUBY = ENV["BUNDLE_RUBY"] || Gem.ruby
+  RUBY = File.realpath(ENV["BUNDLE_RUBY"] || Gem.ruby)
 
   def setup
     ARGV.clear
