@@ -2,7 +2,7 @@
 require File.expand_path("../helper", __FILE__)
 require "open3"
 
-class TestBacktraceSuppression < Rake::TestCase
+class TestBacktraceSuppression < Rake::TestCase # :nodoc:
   def test_bin_rake_suppressed
     paths = ["something/bin/rake:12"]
 
@@ -36,7 +36,7 @@ class TestBacktraceSuppression < Rake::TestCase
   end
 end
 
-class TestRakeBacktrace < Rake::TestCase
+class TestRakeBacktrace < Rake::TestCase # :nodoc:
   include RubyRunner
 
   def setup
